#
# spec file for package python-HyperKitty
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global webapps_dir /srv/www/webapps

%global hyperkitty_pkgname   HyperKitty

%global hyperkitty_basedir   %{webapps_dir}/mailman/hyperkitty
%global hyperkitty_localedir %{hyperkitty_basedir}/locale
%global hyperkitty_staticdir %{hyperkitty_basedir}/static

%global hyperkitty_etcdir    %{_sysconfdir}/hyperkitty
%global hyperkitty_libdir    %{_localstatedir}/lib/hyperkitty
%global hyperkitty_logdir    %{_localstatedir}/log/hyperkitty
%global hyperkitty_datadir   %{hyperkitty_libdir}/data

%global hyperkitty_services hyperkitty-qcluster.service hyperkitty-runjob-daily.service hyperkitty-runjob-daily.timer hyperkitty-runjob-hourly.service hyperkitty-runjob-hourly.timer hyperkitty-runjob-minutely.service hyperkitty-runjob-minutely.timer hyperkitty-runjob-monthly.service hyperkitty-runjob-monthly.timer hyperkitty-runjob-quarter-hourly.service hyperkitty-runjob-quarter-hourly.timer hyperkitty-runjob-weekly.service hyperkitty-runjob-weekly.timer hyperkitty-runjob-yearly.service hyperkitty-runjob-yearly.timer

%if 0%{?suse_version} >= 1550
# Newest python supported by mailman is Python 3.9 -- https://gitlab.com/mailman/mailman/-/issues/936
%define pythons python39
%define mypython python39
%define __mypython %{__python39}
%define mypython_sitelib %{python39_sitelib}
%else
%{?sle15_python_module_pythons}
%define pythons python311
%define mypython python3
%define __mypython %{__python3}
%define mypython_sitelib %{python3_sitelib}
%endif

Name:           python-HyperKitty
Version:        1.3.7
Release:        1.1
Summary:        A web interface to access GNU Mailman v3 archives
License:        GPL-3.0-only
URL:            https://gitlab.com/mailman/hyperkitty
#
Source0:        https://files.pythonhosted.org/packages/source/H/HyperKitty/HyperKitty-%{version}.tar.gz
Source1:        python-HyperKitty-rpmlintrc
#
Source10:       hyperkitty-manage.sh
Source12:       hyperkitty.uwsgi
#
Source20:       hyperkitty-qcluster.service
Source21:       hyperkitty-runjob.service
Source22:       hyperkitty-runjob.timer
#
Source30:       README.SUSE.md
#
# PATCH-FIX-OPENSUSE hyperkitty-settings.patch mcepl@suse.com
# hard-code locations of configuration files
Patch0:         hyperkitty-settings.patch
# PATCH-FIX-UPSTREAM fix-elasticsearch8.patch gl#mailman/hyperkitty#468
Patch1:         fix-elasticsearch8.patch
#
BuildRequires:  %{python_module django-debug-toolbar >= 2.2}
BuildRequires:  %{python_module isort}
BuildRequires:  %{python_module libsass}
BuildRequires:  %{python_module mistune >= 2.0}
BuildRequires:  %{python_module setuptools}
BuildRequires:  acl
BuildRequires:  fdupes
BuildRequires:  openssl
BuildRequires:  python-rpm-macros
BuildRequires:  rsync
BuildRequires:  sudo
BuildArch:      noarch
%if 0%{?suse_version} >= 1550
# use the real python3 primary for rpm pythondistdeps.py
BuildRequires:  python3-packaging
BuildRequires:  sassc
%endif
# SECTION test requirements
BuildRequires:  %{python_module Django >= 1.11}
BuildRequires:  %{python_module Whoosh >= 2.5.7}
BuildRequires:  %{python_module beautifulsoup4 >= 4.3.2}
BuildRequires:  %{python_module django-compressor >= 1.3}
BuildRequires:  %{python_module django-extensions >= 1.3.7}
BuildRequires:  %{python_module django-gravatar2 >= 1.0.6}
BuildRequires:  %{python_module django-haystack >= 2.8.0}
BuildRequires:  %{python_module django-mailman3 >= 1.3.8}
BuildRequires:  %{python_module django-q >= 1.3.9}
BuildRequires:  %{python_module djangorestframework >= 3.0.0}
BuildRequires:  %{python_module elasticsearch}
BuildRequires:  %{python_module flufl.lock}
BuildRequires:  %{python_module lxml}
BuildRequires:  %{python_module mailmanclient >= 3.3.2}
BuildRequires:  %{python_module mistune}
BuildRequires:  %{python_module networkx >= 1.9.1}
BuildRequires:  %{python_module pytest-django}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module python-dateutil >= 2.0}
BuildRequires:  %{python_module pytz >= 2012}
BuildRequires:  %{python_module robot-detection >= 0.3}
# /SECTION

%description
A web interface to access GNU Mailman v3 archives.

%package -n %{hyperkitty_pkgname}
Summary:        A web interface to access GNU Mailman v3 archives
Requires:       %{mypython}-Django >= 1.11
Requires:       %{mypython}-django-compressor >= 1.3
Requires:       %{mypython}-django-debug-toolbar >= 2.2
Requires:       %{mypython}-django-extensions >= 1.3.7
Requires:       %{mypython}-django-gravatar2 >= 1.0.6
Requires:       %{mypython}-django-haystack >= 2.8.0
Requires:       %{mypython}-django-mailman3 >= 1.3.7
Requires:       %{mypython}-django-q >= 1.3.9
Requires:       %{mypython}-djangorestframework >= 3.0.0
Requires:       %{mypython}-flufl.lock
Requires:       %{mypython}-libsass
Requires:       %{mypython}-mailmanclient >= 3.3.2
Requires:       %{mypython}-mistune
Requires:       %{mypython}-networkx >= 1.9.1
Requires:       %{mypython}-python-dateutil >= 2.0
Requires:       %{mypython}-pytz >= 2012
Requires:       %{mypython}-robot-detection >= 0.3
Requires:       %{mypython}-xapian-haystack >= 2.1.0
%if "%{expand:%%%{mypython}_provides}" == "python3"
Provides:       python3-%{hyperkitty_pkgname} = %{version}-%{release}
%endif
Obsoletes:      python3-%{hyperkitty_pkgname} < %{version}-%{release}
Provides:       %{mypython}-%{hyperkitty_pkgname} = %{version}-%{release}
Obsoletes:      %{mypython}-%{hyperkitty_pkgname} < %{version}-%{release}
%if 0%{?suse_version} >= 1550
Requires:       sassc
%endif

%description -n %{hyperkitty_pkgname}
A web interface to access GNU Mailman v3 archives.

%package -n %{hyperkitty_pkgname}-web
Summary:        The webroot for GNU Mailman
Requires:       %{hyperkitty_pkgname}
Requires:       acl
Requires:       openssl
Requires:       sudo

%description -n %{hyperkitty_pkgname}-web
A web user interface for GNU Mailman.

This package holds the web interface.

%package -n %{hyperkitty_pkgname}-web-uwsgi
Summary:        HyperKitty - uwsgi configuration
Requires:       %{hyperkitty_pkgname}-web
%if 0%{suse_version} >= 1550
Requires:       %{mypython}-uwsgi-python3
%else
Requires:       uwsgi-python3
%endif

%description -n %{hyperkitty_pkgname}-web-uwsgi
A web user interface for GNU Mailman.

This package holds the uwsgi configuration.

%prep
%setup -n HyperKitty-%{version}
cp %{SOURCE30} .
touch settings_local.py

# Copy example_project to just build the static files
rsync -a example_project/* build_static_files

%patch0 -p1
%patch1 -p1

%build
sed -i 's|^#!/usr/bin/env.*|#!%{__mypython}|' \
    example_project/manage.py
sed -i 's|/usr/bin/python3|%{__mypython}|' %{SOURCE10} %{SOURCE20} %{SOURCE21}
sed -i 's|python3|%{mypython}|' %{SOURCE12}

%python_build

# Build static files
export PYTHONPATH=$(pwd)
%python_exec build_static_files/manage.py collectstatic --clear --noinput
%python_exec build_static_files/manage.py compress --force

%install
install -d -m 0750 \
    %{buildroot}%{hyperkitty_etcdir} \
    %{buildroot}%{hyperkitty_libdir} \
    %{buildroot}%{hyperkitty_datadir} \
    %{buildroot}%{hyperkitty_datadir}/attachments \
    %{buildroot}%{hyperkitty_logdir}

install -d -m 0755 \
    %{buildroot}%{hyperkitty_basedir} \
    %{buildroot}%{hyperkitty_localedir} \
    %{buildroot}%{hyperkitty_staticdir} \
    %{buildroot}%{hyperkitty_staticdir}/CACHE \
    %{buildroot}%{_unitdir}

%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

# Copy static files
rsync -a build_static_files/static %{buildroot}%{hyperkitty_basedir}
# Remove the directory
rm -rf %{buildroot}%{python_sitelib}/build_static_files

rsync -a example_project/* %{buildroot}%{hyperkitty_basedir}
chmod -x %{buildroot}%{hyperkitty_basedir}/wsgi.py

for f in \
         README.rst \
         apache.conf \
         crontab \
         qcluster.service \
    ; do
    rm -f %{buildroot}%{hyperkitty_basedir}/$f
done
rm -f %{buildroot}%{hyperkitty_localedir}/.keep
rm -f %{buildroot}%{hyperkitty_basedir}/logs/.keep

%python_expand rm -rf %{buildroot}%{$python_sitelib}/example_project

# Create an empty settings_local.py. This will be filled with a SECRET_KEY in post
install -m 0644 settings_local.py %{buildroot}%{hyperkitty_etcdir}/settings_local.py

ln -svf %{hyperkitty_etcdir}/settings_local.py \
    %{buildroot}/%{hyperkitty_basedir}/settings_local.py

%fdupes %{buildroot}%{hyperkitty_basedir}

# Manage script
install -d -m 0755 %{buildroot}%{_sbindir}
install -m 0750 %{SOURCE10} %{buildroot}%{_sbindir}/hyperkitty-manage

install -d -m 0755 %{buildroot}%{_sysconfdir}/uwsgi/vassals
install -m 0644 %{SOURCE12} %{buildroot}%{_sysconfdir}/uwsgi/vassals/hyperkitty.ini

install -m 0644 %{SOURCE20} %{buildroot}%{_unitdir}/hyperkitty-qcluster.service
ln -s /sbin/service %{buildroot}%{_sbindir}/rchyperkitty-qcluster

for job in \
           minutely \
           quarter-hourly \
           hourly \
           daily \
           weekly \
           monthly \
           yearly \
           ; do
    install -m 0644 %{SOURCE21} %{buildroot}%{_unitdir}/hyperkitty-runjob-${job}.service
    sed -i "s/@HYPERKITTY_RUNJOB@/${job}/g" %{buildroot}%{_unitdir}/hyperkitty-runjob-${job}.service
    ln -s /sbin/service %{buildroot}%{_sbindir}/rchyperkitty-runjob-${job}

    install -m 0644 %{SOURCE22} %{buildroot}%{_unitdir}/hyperkitty-runjob-${job}.timer

    hyperkitty_runjob_calendar="OnCalendar=${job}"
    hyperkitty_runjob_delay="RandomizedDelaySec=15m"
    hyperkitty_runjob_name="${job}"

    if [ "${job}" = "minutely" ]; then
        hyperkitty_runjob_delay="RandomizedDelaySec=15s"
    elif [ "${job}" = "quarter-hourly" ]; then
        hyperkitty_runjob_calendar="OnCalendar=*:0/15"
        hyperkitty_runjob_delay="RandomizedDelaySec=2m"
        # The real jobname is with an underscore
        hyperkitty_runjob_name="quarter_hourly"
    fi
    sed -i "s#@HYPERKITTY_RUNJOB_CALENDAR@#${hyperkitty_runjob_calendar}#g" %{buildroot}%{_unitdir}/hyperkitty-runjob-${job}.timer
    sed -i "s#@HYPERKITTY_RUNJOB_DELAY@#${hyperkitty_runjob_delay}#g" %{buildroot}%{_unitdir}/hyperkitty-runjob-${job}.timer
    sed -i "s#@HYPERKITTY_RUNJOB@#${hyperkitty_runjob_name}#g" %{buildroot}%{_unitdir}/hyperkitty-runjob-${job}.timer
done

%check
export PYTHONPATH="$(pwd)"
export LANG=C.UTF-8
%pytest

%pre -n %{hyperkitty_pkgname}-web
/usr/sbin/groupadd -r hyperkitty &>/dev/null || :
/usr/sbin/useradd  -g hyperkitty -s /bin/false -r -c "HyperKitty" -d %{hyperkitty_basedir} hyperkitty &>/dev/null || :

%service_add_pre %{hyperkitty_services}

%post -n %{hyperkitty_pkgname}-web
# We need a SECRET_KEY for manage to work
if ! grep -q "^SECRET_KEY.*" %{hyperkitty_etcdir}/settings_local.py; then
    echo "SECRET_KEY='$(openssl rand -base64 48)'" >> %{hyperkitty_etcdir}/settings_local.py
fi
%{_sbindir}/hyperkitty-manage makemigrations --pythonpath /srv/www/webapps/mailman/hyperkitty/ --settings settings
%{_sbindir}/hyperkitty-manage migrate --pythonpath /srv/www/webapps/mailman/hyperkitty/ --settings settings

%service_add_post %{hyperkitty_services}

%preun -n %{hyperkitty_pkgname}-web
%service_del_preun %{hyperkitty_services}

%postun -n %{hyperkitty_pkgname}-web
%service_del_postun %{hyperkitty_services}

%files -n %{hyperkitty_pkgname}
%doc AUTHORS.txt README.rst example_project doc/*.rst
%license COPYING.txt
%{mypython_sitelib}/hyperkitty
%{mypython_sitelib}/HyperKitty-%{version}*-info

%files -n %{hyperkitty_pkgname}-web
%doc README.SUSE.md
%{_sbindir}/hyperkitty-manage
%{_sbindir}/rchyperkitty-qcluster
%{_sbindir}/rchyperkitty-runjob-*
%dir %{webapps_dir}
%dir %{webapps_dir}/mailman
%{_unitdir}/hyperkitty-qcluster.service
%{_unitdir}/hyperkitty-runjob-*.service
%{_unitdir}/hyperkitty-runjob-*.timer

%defattr(-,root,hyperkitty)
%dir %{hyperkitty_basedir}
%{hyperkitty_basedir}/__init__.py
%{hyperkitty_basedir}/manage.py
%{hyperkitty_basedir}/settings.py
%{hyperkitty_basedir}/settings_local.py
%{hyperkitty_basedir}/urls.py
%{hyperkitty_basedir}/wsgi.py

%dir %{hyperkitty_basedir}/static
%{hyperkitty_basedir}/static/admin
%{hyperkitty_basedir}/static/debug_toolbar
%{hyperkitty_basedir}/static/django-mailman3
%{hyperkitty_basedir}/static/django_extensions
%{hyperkitty_basedir}/static/hyperkitty
%{hyperkitty_basedir}/static/rest_framework

# The wsgi needs to write to static/CACHE
%attr(755,hyperkitty,hyperkitty) %dir %{hyperkitty_basedir}/static/CACHE
%attr(644,hyperkitty,hyperkitty) %{hyperkitty_basedir}/static/CACHE/manifest.json

%attr(755,hyperkitty,hyperkitty) %dir %{hyperkitty_basedir}/static/CACHE/css
%attr(644,hyperkitty,hyperkitty) %{hyperkitty_basedir}/static/CACHE/css/output.*.css

%attr(755,hyperkitty,hyperkitty) %dir %{hyperkitty_basedir}/static/CACHE/js
%attr(644,hyperkitty,hyperkitty) %{hyperkitty_basedir}/static/CACHE/js/output.*.js

%dir %{hyperkitty_localedir}

%attr(750,root,hyperkitty) %dir %{hyperkitty_etcdir}
%attr(640,root,hyperkitty) %config(noreplace) %{hyperkitty_etcdir}/settings_local.py
%attr(750,root,hyperkitty) %dir %{hyperkitty_libdir}
%attr(750,hyperkitty,hyperkitty) %dir %{hyperkitty_datadir}
%attr(770,hyperkitty,hyperkitty) %dir %{hyperkitty_logdir}

%files -n %{hyperkitty_pkgname}-web-uwsgi
%dir %{_sysconfdir}/uwsgi
%dir %{_sysconfdir}/uwsgi/vassals
%config (noreplace) %{_sysconfdir}/uwsgi/vassals/hyperkitty.ini

%changelog
* Sun Jun 18 2023 Andreas Schneider <asn@cryptomilk.org>
- Update to version 1.3.7
  * ``hyperkitty_import`` will now import messages to a list with archiving
    disabled.  (Closes #451)
  * Add support for Python 3.11.
- Use sle15_python_module_pythons
* Wed Apr  5 2023 Andreas Schneider <asn@cryptomilk.org>
- Add missing requires for sassc used by manage.py
* Mon Nov 21 2022 Andreas Schneider <asn@cryptomilk.org>
- Update to version 1.3.6
  * Fixed an issue in hyperkitty_import with an empty Message-ID. (Closes #396)
  * Set Q_CLUSTER retry > timeout in example_project. (Closes #402)
  * Set DEFAULT_AUTO_FIELD to silence errors with Django >= 3.2.
  * Require mistune >= 2.0.0 and fix a problem with importing from it. (Closes
    [#395])
  * Adapt parsing of emails to be compatible with python 3.10. (Closes #401)
  * Add gitlab-ci integration for python 3.10.
  * Skip lists with private archives in the find list search. (Closes #237)
  * Add a new setting HYPERKITTY_MBOX_EXPORT which, when set to false, removes
    the :guilabel:`Download` button and disables the export view. ( Fixes #386)
  * Return 400 instead of 500 when the sort mode is invalid. (Fixes #270)
  * Allow HyperKitty to find attachments in either the database or the
    HYPERKITTY_ATTACHMENT_FOLDER. (Closes #213)
  * Implemented a new attachments_to_file management command to move attachment
    content to the file system after setting HYPERKITTY_ATTACHMENT_FOLDER.
    (Closes #413)
  * Handle exception when a banned address tries to post. (Fixes #325)
  * Add an index on the 'name' column (fqdn)for the MailingList table since it
    is most frequently used to query the MailingList object.
  * Add the ability to view a thread without Javascript enabled. This uses the
    same mechanism we use with bot-detection and rendering of the entire page
    at once, which will be slow to load but allow reading. (See #422)
  * Improve the performance of the thread view for logged-in users by
    optimizing the total database calls made. (See !409)
  * Add support for Django <= 4.1
  * Remove support for Django < 3.2
  * Remove support for Python 3.6
  * Fix tests to be compatible with Python 3.10
  * Replace use of mock with unittest.mock in all tests. (Closes #429)
  * The check for writability of HYPERKITTY_ATTACHMENT_FOLDER when set has been
    improved to avoid a potential race condition. (Closes #389)
- Run complete testsuite with pytest
- Removed hyperkitty-django4.patch
- Removed hyperkitty-fix-mistune-2.0-imports.patch
- Removed python-HyperKitty-no-mock.patch
- Removed hyperkitty-fix-qcluster-timeout.patch
- Removed hyperkitty-fix-py310-tests.patch
- Removed fix-django41.patch
* Thu Oct  6 2022 Daniel Garcia <daniel.garcia@suse.com>
- Add fix-django41.patch to fix issues with django4.1
- Add fix-elasticsearch8.patch to fix issues with elasticsearch 8.0.0
* Mon Jul  4 2022 Ben Greiner <code@bnavigator.de>
- Rename the built package to python prefixless HyperKitty
  * Doesn't imply any false impression of multiflavor
- Go back to python39 -- highest supported Python by mailman
* Sun Jul  3 2022 Ben Greiner <code@bnavigator.de>
- Add hyperkitty-fix-py310-tests.patch
  * Fix test failures on Python 3.10 (and Python 3.9.13)
  * https://gitlab.com/mailman/hyperkitty/-/issues/401
  * https://gitlab.com/mailman/hyperkitty/-/merge_requests/381
  * https://gitlab.com/mailman/hyperkitty/-/merge_requests/449
* Sat Jul  2 2022 Andreas Schneider <asn@cryptomilk.org>
- Fix django warning that timeout is bigger than retry
  * Added hyperkitty-fix-qcluster-timeout.patch
* Fri Jun 10 2022 Andreas Schneider <asn@cryptomilk.org>
- First Make migrations on update, then call migrate
* Thu May 26 2022 pgajdos@suse.com
- do not require python-mock for build
- added patches
  fix https://gitlab.com/mailman/hyperkitty/-/issues/429
  + python-HyperKitty-no-mock.patch
* Tue Dec 28 2021 John Vandenberg <jayvdb@gmail.com>
- Add hyperkitty-django4.patch to support Django 4
* Fri Dec 17 2021 Matej Cepl <mcepl@suse.com>
- Add hyperkitty-fix-mistune-2.0-imports.patch ... two function
  moved in mistune 2.0 (gl#mailman/hyperkitty#379).
* Thu Dec 16 2021 Sasi Olin <hel@lcp.world>
- Add a patch that fixes compatibility with the full release of mistune 2.0
* Wed Nov 17 2021 Andreas Schneider <asn@cryptomilk.org>
- Update to version 1.3.5
  * https://gitlab.com/mailman/hyperkitty/-/blob/1.3.5/doc/news.rst
- Fixes CVE-2021-35057
- Removed obsolete python-HyperKitty-CVE-2021-33038.patch
* Wed Jun  2 2021 Andreas Schneider <asn@cryptomilk.org>
- Fix log dir permissions
* Wed Jun  2 2021 pgajdos@suse.com
- security update
- added patches
  fix CVE-2021-33038 [bsc#1186575], information disclosure when importing a private mailing list
  + python-HyperKitty-CVE-2021-33038.patch
* Wed May 26 2021 Andreas Schneider <asn@cryptomilk.org>
- Remove the hyperkitty-admin user
* Tue May 25 2021 Andreas Schneider <asn@cryptomilk.org>
- Create static files as part of the build process
- Fixed CVE-2021-25322
* Tue May  4 2021 Ben Greiner <code@bnavigator.de>
- restrict to primary python3 flavor due to mailman
* Wed Feb  3 2021 Andreas Schneider <asn@cryptomilk.org>
- Update to version 1.3.4
  * Sync owners and moderators from Mailman Core for MailingList. (Fixes #302)
  * Implemented a new HYPERKITTY_JOBS_UPDATE_INDEX_LOCK_LIFE setting to set the
    lock lifetime for the update_and_clean_index job. (Closes #300)
  * Implemented a new HYPERKITTY_ALLOW_WEB_POSTING that allows disabling the
    web posting feature. (Closes #264)
  * Add the ability to disable Gravatar using HYPERKITTY_ENABLE_GRAVATAR
    settings. (Closes #303)
  * Replaced deprecated ugettext functions with gettext. (Closes #310)
  * Fix export of Email message where the In-Reply-To header doesn’t include
    the <> brackets. (Closes #331)
  * We now catch a few more exceptions in hyperkitty_import when getting
    messages from a mbox. (Closes #313 and #314)
  * Added a new contrib/check_hk_import script to check mboxes before running
    hyperkitty_import.
  * We now ignore a ValueError in hyperkitty_import when trying to replace a
    Subject: header. (Closes #317)
  * hyperkitty_import now includes the mbox name in error messages when
    importing multiple mboxes. (Closes #318)
  * `` at `` is now only replaced with @ in From: header values when necessary
    and not unconditionally. (Closes #320)
  * The wildcard notation for any host '*' is now supported into
    MAILMAN_ARCHVER_FROM to disable Hyperkitty clients IP checking.
  * Join the searchbar and search button like it was before bootstrap 4
    migration. (See !301)
  * Use the umd builds for popper.js instead of the regular ones. (See !309)
  * Exceptions thrown by smtplib in sending replies are now caught and give an
    appropriate error message. (Closes #309)
- Removed hyperkitty-fix-tests.patch
- Fixed build on tumbleweed
* Mon Dec 28 2020 Andreas Schneider <asn@cryptomilk.org>
- Fix quarter hourly timer
* Sun Dec 20 2020 Andreas Schneider <asn@cryptomilk.org>
- Fix access to CACHE dir
- Improve documentation (README.SUSE.md)
- Fix quaterly timer and service
* Sun Dec 13 2020 Andreas Schneider <asn@cryptomilk.org>
- Added hyperkitty-qcluster.service
- Added hyperkitty-runjob.service and hyperkitty-runjob.timer
* Sat Dec 12 2020 Andreas Schneider <asn@cryptomilk.org>
- Create a HyperKitty-web package with webroot files
- Create a HyperKitty-web-uwsgi with uwsgi configuration
- Added hyperkitty-settings.patch
  * Sets the FHS default paths
- Added hyperkitty-fix-tests.patch
  * Make migration compatible with django >= 3.1
- Added rpmlint config
* Tue Aug  4 2020 Stasiek Michalski <stasiek@michalski.cc>
- Version update to 1.3.3
  * Allow SHOW_INACTIVE_LISTS_DEFAULT setting to be configurable. (Closes #276)
  * Fix a bug where the user couldn’t chose the address to send reply or new post as. (Closes #288)
  * Improve the Django admin command reference from hyperkitty_import. (Closes #281)
  * Fix FILTER_VHOST to work with web hosts other than the email host. (Closes #254)
  * Fixed a bug where export can fail if certain headers are wrapped. (Closes #292)
  * Fixed hyperkitty_import to allow odd line endings in a folded message subject. (Closes #280)
  * Fixed a bug that could throw an IndexError when exporting messages. (Closes #293)
  * Use errors='replace' when encoding attachments. (Closes #294)
- Drop merged python-HyperKitty-remove-legacy-use-of-available_attrs.patch
* Thu May 14 2020 pgajdos@suse.com
- version update to 1.3.2
  - Remove support for Django 1.11. (Closes #273)
  - Skip ``Thread.DoesNotExist`` exception when raised within
    ``rebuild_thread_cache_votes``. (Closes #245)
  - Send 400 status code for ``ValueError`` when archiving. (Closes #271)
  - Fix a bug where exception for elasticsearch backend would not be caught. (Closes #263)
- added patches
  https://gitlab.com/mailman/hyperkitty/-/commit/03c99ad5beefeac4474b5a00c840fd9debccba02
  + python-HyperKitty-remove-legacy-use-of-available_attrs.patch
* Fri Jan 10 2020 pgajdos@suse.com
- fix dependency (django_compressor -> django-compressor)
* Tue Dec 10 2019 pgajdos@suse.com
- version update to 1.3.1
  * Add support to delete mailing list. (Closes #3)
  * Fix a bug where messages with attachments would skip adding the body when
    exporting the email. (Closes #252)
  * Fix a bug where exporting mbox with messages that have attachments saved
    to disk would raise exception and return a corrupt mbox. (Closes #258)
  * Fix a bug where downloaded attachments are returned as a memoryview object
    instead of bytes and hence fail to download. (Closes #247)
  * Fix a bug where migrations would fail with exceptions on postgresl. (Closes
    [#266])
  * Add support for Django 3.0.
* Mon Dec  2 2019 pgajdos@suse.com
- call spec-cleaner
* Wed Nov 27 2019 pgajdos@suse.com
- package documentation
* Wed Nov 27 2019 pgajdos@suse.com
- require python-libsass
* Thu Nov 14 2019 pgajdos@suse.com
- run the testsuite correctly
* Tue Oct  1 2019 pgajdos@suse.com
- initial version 1.3.0 [SLE-7686]
